# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/matchable_resource.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import cluster_assignment_pb2 as flyteidl_dot_admin_dot_cluster__assignment__pb2
from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/matchable_resource.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\'flyteidl/admin/matchable_resource.proto\x12\x0e\x66lyteidl.admin\x1a\'flyteidl/admin/cluster_assignment.proto\x1a\x1d\x66lyteidl/core/execution.proto\"h\n\x10TaskResourceSpec\x12\x0b\n\x03\x63pu\x18\x01 \x01(\t\x12\x0b\n\x03gpu\x18\x02 \x01(\t\x12\x0e\n\x06memory\x18\x03 \x01(\t\x12\x0f\n\x07storage\x18\x04 \x01(\t\x12\x19\n\x11\x65phemeral_storage\x18\x05 \x01(\t\"~\n\x16TaskResourceAttributes\x12\x32\n\x08\x64\x65\x66\x61ults\x18\x01 \x01(\x0b\x32 .flyteidl.admin.TaskResourceSpec\x12\x30\n\x06limits\x18\x02 \x01(\x0b\x32 .flyteidl.admin.TaskResourceSpec\"\x9d\x01\n\x19\x43lusterResourceAttributes\x12M\n\nattributes\x18\x01 \x03(\x0b\x32\x39.flyteidl.admin.ClusterResourceAttributes.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"(\n\x18\x45xecutionQueueAttributes\x12\x0c\n\x04tags\x18\x01 \x03(\t\"&\n\x15\x45xecutionClusterLabel\x12\r\n\x05value\x18\x01 \x01(\t\"\xc1\x01\n\x0ePluginOverride\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x11\n\tplugin_id\x18\x02 \x03(\t\x12U\n\x17missing_plugin_behavior\x18\x04 \x01(\x0e\x32\x34.flyteidl.admin.PluginOverride.MissingPluginBehavior\"2\n\x15MissingPluginBehavior\x12\x08\n\x04\x46\x41IL\x10\x00\x12\x0f\n\x0bUSE_DEFAULT\x10\x01\"D\n\x0fPluginOverrides\x12\x31\n\toverrides\x18\x01 \x03(\x0b\x32\x1e.flyteidl.admin.PluginOverride\"2\n\x17WorkflowExecutionConfig\x12\x17\n\x0fmax_parallelism\x18\x01 \x01(\x05\"\xe1\x04\n\x12MatchingAttributes\x12J\n\x18task_resource_attributes\x18\x01 \x01(\x0b\x32&.flyteidl.admin.TaskResourceAttributesH\x00\x12P\n\x1b\x63luster_resource_attributes\x18\x02 \x01(\x0b\x32).flyteidl.admin.ClusterResourceAttributesH\x00\x12N\n\x1a\x65xecution_queue_attributes\x18\x03 \x01(\x0b\x32(.flyteidl.admin.ExecutionQueueAttributesH\x00\x12H\n\x17\x65xecution_cluster_label\x18\x04 \x01(\x0b\x32%.flyteidl.admin.ExecutionClusterLabelH\x00\x12=\n\x12quality_of_service\x18\x05 \x01(\x0b\x32\x1f.flyteidl.core.QualityOfServiceH\x00\x12;\n\x10plugin_overrides\x18\x06 \x01(\x0b\x32\x1f.flyteidl.admin.PluginOverridesH\x00\x12L\n\x19workflow_execution_config\x18\x07 \x01(\x0b\x32\'.flyteidl.admin.WorkflowExecutionConfigH\x00\x12?\n\x12\x63luster_assignment\x18\x08 \x01(\x0b\x32!.flyteidl.admin.ClusterAssignmentH\x00\x42\x08\n\x06target\"\xa2\x01\n MatchableAttributesConfiguration\x12\x36\n\nattributes\x18\x01 \x01(\x0b\x32\".flyteidl.admin.MatchingAttributes\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x10\n\x08workflow\x18\x04 \x01(\t\x12\x13\n\x0blaunch_plan\x18\x05 \x01(\t\"Z\n\x1eListMatchableAttributesRequest\x12\x38\n\rresource_type\x18\x01 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"k\n\x1fListMatchableAttributesResponse\x12H\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32\x30.flyteidl.admin.MatchableAttributesConfiguration*\xe0\x01\n\x11MatchableResource\x12\x11\n\rTASK_RESOURCE\x10\x00\x12\x14\n\x10\x43LUSTER_RESOURCE\x10\x01\x12\x13\n\x0f\x45XECUTION_QUEUE\x10\x02\x12\x1b\n\x17\x45XECUTION_CLUSTER_LABEL\x10\x03\x12$\n QUALITY_OF_SERVICE_SPECIFICATION\x10\x04\x12\x13\n\x0fPLUGIN_OVERRIDE\x10\x05\x12\x1d\n\x19WORKFLOW_EXECUTION_CONFIG\x10\x06\x12\x16\n\x12\x43LUSTER_ASSIGNMENT\x10\x07\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_cluster__assignment__pb2.DESCRIPTOR,flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,])

_MATCHABLERESOURCE = _descriptor.EnumDescriptor(
  name='MatchableResource',
  full_name='flyteidl.admin.MatchableResource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TASK_RESOURCE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_RESOURCE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTION_QUEUE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTION_CLUSTER_LABEL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUALITY_OF_SERVICE_SPECIFICATION', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLUGIN_OVERRIDE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORKFLOW_EXECUTION_CONFIG', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLUSTER_ASSIGNMENT', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1904,
  serialized_end=2128,
)
_sym_db.RegisterEnumDescriptor(_MATCHABLERESOURCE)

MatchableResource = enum_type_wrapper.EnumTypeWrapper(_MATCHABLERESOURCE)
TASK_RESOURCE = 0
CLUSTER_RESOURCE = 1
EXECUTION_QUEUE = 2
EXECUTION_CLUSTER_LABEL = 3
QUALITY_OF_SERVICE_SPECIFICATION = 4
PLUGIN_OVERRIDE = 5
WORKFLOW_EXECUTION_CONFIG = 6
CLUSTER_ASSIGNMENT = 7


_PLUGINOVERRIDE_MISSINGPLUGINBEHAVIOR = _descriptor.EnumDescriptor(
  name='MissingPluginBehavior',
  full_name='flyteidl.admin.PluginOverride.MissingPluginBehavior',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USE_DEFAULT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=751,
  serialized_end=801,
)
_sym_db.RegisterEnumDescriptor(_PLUGINOVERRIDE_MISSINGPLUGINBEHAVIOR)


_TASKRESOURCESPEC = _descriptor.Descriptor(
  name='TaskResourceSpec',
  full_name='flyteidl.admin.TaskResourceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu', full_name='flyteidl.admin.TaskResourceSpec.cpu', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpu', full_name='flyteidl.admin.TaskResourceSpec.gpu', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory', full_name='flyteidl.admin.TaskResourceSpec.memory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='flyteidl.admin.TaskResourceSpec.storage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ephemeral_storage', full_name='flyteidl.admin.TaskResourceSpec.ephemeral_storage', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=235,
)


_TASKRESOURCEATTRIBUTES = _descriptor.Descriptor(
  name='TaskResourceAttributes',
  full_name='flyteidl.admin.TaskResourceAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='defaults', full_name='flyteidl.admin.TaskResourceAttributes.defaults', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limits', full_name='flyteidl.admin.TaskResourceAttributes.limits', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=363,
)


_CLUSTERRESOURCEATTRIBUTES_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='flyteidl.admin.ClusterResourceAttributes.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.admin.ClusterResourceAttributes.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.ClusterResourceAttributes.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=523,
)

_CLUSTERRESOURCEATTRIBUTES = _descriptor.Descriptor(
  name='ClusterResourceAttributes',
  full_name='flyteidl.admin.ClusterResourceAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.ClusterResourceAttributes.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERRESOURCEATTRIBUTES_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=523,
)


_EXECUTIONQUEUEATTRIBUTES = _descriptor.Descriptor(
  name='ExecutionQueueAttributes',
  full_name='flyteidl.admin.ExecutionQueueAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='flyteidl.admin.ExecutionQueueAttributes.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=565,
)


_EXECUTIONCLUSTERLABEL = _descriptor.Descriptor(
  name='ExecutionClusterLabel',
  full_name='flyteidl.admin.ExecutionClusterLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.admin.ExecutionClusterLabel.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=605,
)


_PLUGINOVERRIDE = _descriptor.Descriptor(
  name='PluginOverride',
  full_name='flyteidl.admin.PluginOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.admin.PluginOverride.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugin_id', full_name='flyteidl.admin.PluginOverride.plugin_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missing_plugin_behavior', full_name='flyteidl.admin.PluginOverride.missing_plugin_behavior', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLUGINOVERRIDE_MISSINGPLUGINBEHAVIOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=801,
)


_PLUGINOVERRIDES = _descriptor.Descriptor(
  name='PluginOverrides',
  full_name='flyteidl.admin.PluginOverrides',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='overrides', full_name='flyteidl.admin.PluginOverrides.overrides', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=871,
)


_WORKFLOWEXECUTIONCONFIG = _descriptor.Descriptor(
  name='WorkflowExecutionConfig',
  full_name='flyteidl.admin.WorkflowExecutionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_parallelism', full_name='flyteidl.admin.WorkflowExecutionConfig.max_parallelism', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=923,
)


_MATCHINGATTRIBUTES = _descriptor.Descriptor(
  name='MatchingAttributes',
  full_name='flyteidl.admin.MatchingAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_resource_attributes', full_name='flyteidl.admin.MatchingAttributes.task_resource_attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_resource_attributes', full_name='flyteidl.admin.MatchingAttributes.cluster_resource_attributes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execution_queue_attributes', full_name='flyteidl.admin.MatchingAttributes.execution_queue_attributes', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execution_cluster_label', full_name='flyteidl.admin.MatchingAttributes.execution_cluster_label', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_of_service', full_name='flyteidl.admin.MatchingAttributes.quality_of_service', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugin_overrides', full_name='flyteidl.admin.MatchingAttributes.plugin_overrides', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_execution_config', full_name='flyteidl.admin.MatchingAttributes.workflow_execution_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_assignment', full_name='flyteidl.admin.MatchingAttributes.cluster_assignment', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='flyteidl.admin.MatchingAttributes.target',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=926,
  serialized_end=1535,
)


_MATCHABLEATTRIBUTESCONFIGURATION = _descriptor.Descriptor(
  name='MatchableAttributesConfiguration',
  full_name='flyteidl.admin.MatchableAttributesConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.MatchableAttributesConfiguration.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.MatchableAttributesConfiguration.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.MatchableAttributesConfiguration.project', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow', full_name='flyteidl.admin.MatchableAttributesConfiguration.workflow', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launch_plan', full_name='flyteidl.admin.MatchableAttributesConfiguration.launch_plan', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1700,
)


_LISTMATCHABLEATTRIBUTESREQUEST = _descriptor.Descriptor(
  name='ListMatchableAttributesRequest',
  full_name='flyteidl.admin.ListMatchableAttributesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.ListMatchableAttributesRequest.resource_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1792,
)


_LISTMATCHABLEATTRIBUTESRESPONSE = _descriptor.Descriptor(
  name='ListMatchableAttributesResponse',
  full_name='flyteidl.admin.ListMatchableAttributesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configurations', full_name='flyteidl.admin.ListMatchableAttributesResponse.configurations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1901,
)

_TASKRESOURCEATTRIBUTES.fields_by_name['defaults'].message_type = _TASKRESOURCESPEC
_TASKRESOURCEATTRIBUTES.fields_by_name['limits'].message_type = _TASKRESOURCESPEC
_CLUSTERRESOURCEATTRIBUTES_ATTRIBUTESENTRY.containing_type = _CLUSTERRESOURCEATTRIBUTES
_CLUSTERRESOURCEATTRIBUTES.fields_by_name['attributes'].message_type = _CLUSTERRESOURCEATTRIBUTES_ATTRIBUTESENTRY
_PLUGINOVERRIDE.fields_by_name['missing_plugin_behavior'].enum_type = _PLUGINOVERRIDE_MISSINGPLUGINBEHAVIOR
_PLUGINOVERRIDE_MISSINGPLUGINBEHAVIOR.containing_type = _PLUGINOVERRIDE
_PLUGINOVERRIDES.fields_by_name['overrides'].message_type = _PLUGINOVERRIDE
_MATCHINGATTRIBUTES.fields_by_name['task_resource_attributes'].message_type = _TASKRESOURCEATTRIBUTES
_MATCHINGATTRIBUTES.fields_by_name['cluster_resource_attributes'].message_type = _CLUSTERRESOURCEATTRIBUTES
_MATCHINGATTRIBUTES.fields_by_name['execution_queue_attributes'].message_type = _EXECUTIONQUEUEATTRIBUTES
_MATCHINGATTRIBUTES.fields_by_name['execution_cluster_label'].message_type = _EXECUTIONCLUSTERLABEL
_MATCHINGATTRIBUTES.fields_by_name['quality_of_service'].message_type = flyteidl_dot_core_dot_execution__pb2._QUALITYOFSERVICE
_MATCHINGATTRIBUTES.fields_by_name['plugin_overrides'].message_type = _PLUGINOVERRIDES
_MATCHINGATTRIBUTES.fields_by_name['workflow_execution_config'].message_type = _WORKFLOWEXECUTIONCONFIG
_MATCHINGATTRIBUTES.fields_by_name['cluster_assignment'].message_type = flyteidl_dot_admin_dot_cluster__assignment__pb2._CLUSTERASSIGNMENT
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['task_resource_attributes'])
_MATCHINGATTRIBUTES.fields_by_name['task_resource_attributes'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['cluster_resource_attributes'])
_MATCHINGATTRIBUTES.fields_by_name['cluster_resource_attributes'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['execution_queue_attributes'])
_MATCHINGATTRIBUTES.fields_by_name['execution_queue_attributes'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['execution_cluster_label'])
_MATCHINGATTRIBUTES.fields_by_name['execution_cluster_label'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['quality_of_service'])
_MATCHINGATTRIBUTES.fields_by_name['quality_of_service'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['plugin_overrides'])
_MATCHINGATTRIBUTES.fields_by_name['plugin_overrides'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['workflow_execution_config'])
_MATCHINGATTRIBUTES.fields_by_name['workflow_execution_config'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHINGATTRIBUTES.oneofs_by_name['target'].fields.append(
  _MATCHINGATTRIBUTES.fields_by_name['cluster_assignment'])
_MATCHINGATTRIBUTES.fields_by_name['cluster_assignment'].containing_oneof = _MATCHINGATTRIBUTES.oneofs_by_name['target']
_MATCHABLEATTRIBUTESCONFIGURATION.fields_by_name['attributes'].message_type = _MATCHINGATTRIBUTES
_LISTMATCHABLEATTRIBUTESREQUEST.fields_by_name['resource_type'].enum_type = _MATCHABLERESOURCE
_LISTMATCHABLEATTRIBUTESRESPONSE.fields_by_name['configurations'].message_type = _MATCHABLEATTRIBUTESCONFIGURATION
DESCRIPTOR.message_types_by_name['TaskResourceSpec'] = _TASKRESOURCESPEC
DESCRIPTOR.message_types_by_name['TaskResourceAttributes'] = _TASKRESOURCEATTRIBUTES
DESCRIPTOR.message_types_by_name['ClusterResourceAttributes'] = _CLUSTERRESOURCEATTRIBUTES
DESCRIPTOR.message_types_by_name['ExecutionQueueAttributes'] = _EXECUTIONQUEUEATTRIBUTES
DESCRIPTOR.message_types_by_name['ExecutionClusterLabel'] = _EXECUTIONCLUSTERLABEL
DESCRIPTOR.message_types_by_name['PluginOverride'] = _PLUGINOVERRIDE
DESCRIPTOR.message_types_by_name['PluginOverrides'] = _PLUGINOVERRIDES
DESCRIPTOR.message_types_by_name['WorkflowExecutionConfig'] = _WORKFLOWEXECUTIONCONFIG
DESCRIPTOR.message_types_by_name['MatchingAttributes'] = _MATCHINGATTRIBUTES
DESCRIPTOR.message_types_by_name['MatchableAttributesConfiguration'] = _MATCHABLEATTRIBUTESCONFIGURATION
DESCRIPTOR.message_types_by_name['ListMatchableAttributesRequest'] = _LISTMATCHABLEATTRIBUTESREQUEST
DESCRIPTOR.message_types_by_name['ListMatchableAttributesResponse'] = _LISTMATCHABLEATTRIBUTESRESPONSE
DESCRIPTOR.enum_types_by_name['MatchableResource'] = _MATCHABLERESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TaskResourceSpec = _reflection.GeneratedProtocolMessageType('TaskResourceSpec', (_message.Message,), dict(
  DESCRIPTOR = _TASKRESOURCESPEC,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.TaskResourceSpec)
  ))
_sym_db.RegisterMessage(TaskResourceSpec)

TaskResourceAttributes = _reflection.GeneratedProtocolMessageType('TaskResourceAttributes', (_message.Message,), dict(
  DESCRIPTOR = _TASKRESOURCEATTRIBUTES,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.TaskResourceAttributes)
  ))
_sym_db.RegisterMessage(TaskResourceAttributes)

ClusterResourceAttributes = _reflection.GeneratedProtocolMessageType('ClusterResourceAttributes', (_message.Message,), dict(

  AttributesEntry = _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLUSTERRESOURCEATTRIBUTES_ATTRIBUTESENTRY,
    __module__ = 'flyteidl.admin.matchable_resource_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.admin.ClusterResourceAttributes.AttributesEntry)
    ))
  ,
  DESCRIPTOR = _CLUSTERRESOURCEATTRIBUTES,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ClusterResourceAttributes)
  ))
_sym_db.RegisterMessage(ClusterResourceAttributes)
_sym_db.RegisterMessage(ClusterResourceAttributes.AttributesEntry)

ExecutionQueueAttributes = _reflection.GeneratedProtocolMessageType('ExecutionQueueAttributes', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONQUEUEATTRIBUTES,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionQueueAttributes)
  ))
_sym_db.RegisterMessage(ExecutionQueueAttributes)

ExecutionClusterLabel = _reflection.GeneratedProtocolMessageType('ExecutionClusterLabel', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCLUSTERLABEL,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionClusterLabel)
  ))
_sym_db.RegisterMessage(ExecutionClusterLabel)

PluginOverride = _reflection.GeneratedProtocolMessageType('PluginOverride', (_message.Message,), dict(
  DESCRIPTOR = _PLUGINOVERRIDE,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.PluginOverride)
  ))
_sym_db.RegisterMessage(PluginOverride)

PluginOverrides = _reflection.GeneratedProtocolMessageType('PluginOverrides', (_message.Message,), dict(
  DESCRIPTOR = _PLUGINOVERRIDES,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.PluginOverrides)
  ))
_sym_db.RegisterMessage(PluginOverrides)

WorkflowExecutionConfig = _reflection.GeneratedProtocolMessageType('WorkflowExecutionConfig', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONCONFIG,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionConfig)
  ))
_sym_db.RegisterMessage(WorkflowExecutionConfig)

MatchingAttributes = _reflection.GeneratedProtocolMessageType('MatchingAttributes', (_message.Message,), dict(
  DESCRIPTOR = _MATCHINGATTRIBUTES,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.MatchingAttributes)
  ))
_sym_db.RegisterMessage(MatchingAttributes)

MatchableAttributesConfiguration = _reflection.GeneratedProtocolMessageType('MatchableAttributesConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _MATCHABLEATTRIBUTESCONFIGURATION,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.MatchableAttributesConfiguration)
  ))
_sym_db.RegisterMessage(MatchableAttributesConfiguration)

ListMatchableAttributesRequest = _reflection.GeneratedProtocolMessageType('ListMatchableAttributesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTMATCHABLEATTRIBUTESREQUEST,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ListMatchableAttributesRequest)
  ))
_sym_db.RegisterMessage(ListMatchableAttributesRequest)

ListMatchableAttributesResponse = _reflection.GeneratedProtocolMessageType('ListMatchableAttributesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTMATCHABLEATTRIBUTESRESPONSE,
  __module__ = 'flyteidl.admin.matchable_resource_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ListMatchableAttributesResponse)
  ))
_sym_db.RegisterMessage(ListMatchableAttributesResponse)


DESCRIPTOR._options = None
_CLUSTERRESOURCEATTRIBUTES_ATTRIBUTESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from flyteidl.service import dataproxy_pb2 as flyteidl_dot_service_dot_dataproxy__pb2


class DataProxyStub(object):
  """DataProxy defines an RPC Service that allows access to user-data in a controlled manner.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateUploadLocation = channel.unary_unary(
        '/flyteidl.service.DataProxy/CreateUploadLocation',
        request_serializer=flyteidl_dot_service_dot_dataproxy__pb2.CreateUploadLocationRequest.SerializeToString,
        response_deserializer=flyteidl_dot_service_dot_dataproxy__pb2.CreateUploadLocationResponse.FromString,
        )


class DataProxyServicer(object):
  """DataProxy defines an RPC Service that allows access to user-data in a controlled manner.
  """

  def CreateUploadLocation(self, request, context):
    """Retrieves user information about the currently logged in user.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataProxyServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateUploadLocation': grpc.unary_unary_rpc_method_handler(
          servicer.CreateUploadLocation,
          request_deserializer=flyteidl_dot_service_dot_dataproxy__pb2.CreateUploadLocationRequest.FromString,
          response_serializer=flyteidl_dot_service_dot_dataproxy__pb2.CreateUploadLocationResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'flyteidl.service.DataProxy', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/datacatalog/datacatalog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/datacatalog/datacatalog.proto',
  package='datacatalog',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n&flyteidl/datacatalog/datacatalog.proto\x12\x0b\x64\x61tacatalog\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"=\n\x14\x43reateDatasetRequest\x12%\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x14.datacatalog.Dataset\"\x17\n\x15\x43reateDatasetResponse\"<\n\x11GetDatasetRequest\x12\'\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x16.datacatalog.DatasetID\";\n\x12GetDatasetResponse\x12%\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x14.datacatalog.Dataset\"x\n\x12GetArtifactRequest\x12\'\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x16.datacatalog.DatasetID\x12\x15\n\x0b\x61rtifact_id\x18\x02 \x01(\tH\x00\x12\x12\n\x08tag_name\x18\x03 \x01(\tH\x00\x42\x0e\n\x0cquery_handle\">\n\x13GetArtifactResponse\x12\'\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32\x15.datacatalog.Artifact\"@\n\x15\x43reateArtifactRequest\x12\'\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32\x15.datacatalog.Artifact\"\x18\n\x16\x43reateArtifactResponse\".\n\rAddTagRequest\x12\x1d\n\x03tag\x18\x01 \x01(\x0b\x32\x10.datacatalog.Tag\"\x10\n\x0e\x41\x64\x64TagResponse\"\xa2\x01\n\x14ListArtifactsRequest\x12\'\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x16.datacatalog.DatasetID\x12-\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1d.datacatalog.FilterExpression\x12\x32\n\npagination\x18\x03 \x01(\x0b\x32\x1e.datacatalog.PaginationOptions\"U\n\x15ListArtifactsResponse\x12(\n\tartifacts\x18\x01 \x03(\x0b\x32\x15.datacatalog.Artifact\x12\x12\n\nnext_token\x18\x02 \x01(\t\"x\n\x13ListDatasetsRequest\x12-\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1d.datacatalog.FilterExpression\x12\x32\n\npagination\x18\x02 \x01(\x0b\x32\x1e.datacatalog.PaginationOptions\"R\n\x14ListDatasetsResponse\x12&\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x14.datacatalog.Dataset\x12\x12\n\nnext_token\x18\x02 \x01(\t\"M\n\rReservationID\x12*\n\ndataset_id\x18\x01 \x01(\x0b\x32\x16.datacatalog.DatasetID\x12\x10\n\x08tag_name\x18\x02 \x01(\t\"\x9c\x01\n\x1dGetOrExtendReservationRequest\x12\x32\n\x0ereservation_id\x18\x01 \x01(\x0b\x32\x1a.datacatalog.ReservationID\x12\x10\n\x08owner_id\x18\x02 \x01(\t\x12\x35\n\x12heartbeat_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xe3\x01\n\x0bReservation\x12\x32\n\x0ereservation_id\x18\x01 \x01(\x0b\x32\x1a.datacatalog.ReservationID\x12\x10\n\x08owner_id\x18\x02 \x01(\t\x12\x35\n\x12heartbeat_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x08metadata\x18\x06 \x01(\x0b\x32\x15.datacatalog.Metadata\"O\n\x1eGetOrExtendReservationResponse\x12-\n\x0breservation\x18\x01 \x01(\x0b\x32\x18.datacatalog.Reservation\"a\n\x19ReleaseReservationRequest\x12\x32\n\x0ereservation_id\x18\x01 \x01(\x0b\x32\x1a.datacatalog.ReservationID\x12\x10\n\x08owner_id\x18\x02 \x01(\t\"\x1c\n\x1aReleaseReservationResponse\"m\n\x07\x44\x61taset\x12\"\n\x02id\x18\x01 \x01(\x0b\x32\x16.datacatalog.DatasetID\x12\'\n\x08metadata\x18\x02 \x01(\x0b\x32\x15.datacatalog.Metadata\x12\x15\n\rpartitionKeys\x18\x03 \x03(\t\"\'\n\tPartition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"Y\n\tDatasetID\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0c\n\x04UUID\x18\x05 \x01(\t\"\x8d\x02\n\x08\x41rtifact\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\x16.datacatalog.DatasetID\x12\'\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x19.datacatalog.ArtifactData\x12\'\n\x08metadata\x18\x04 \x01(\x0b\x32\x15.datacatalog.Metadata\x12*\n\npartitions\x18\x05 \x03(\x0b\x32\x16.datacatalog.Partition\x12\x1e\n\x04tags\x18\x06 \x03(\x0b\x32\x10.datacatalog.Tag\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x0c\x41rtifactData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.flyteidl.core.Literal\"Q\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x61rtifact_id\x18\x02 \x01(\t\x12\'\n\x07\x64\x61taset\x18\x03 \x01(\x0b\x32\x16.datacatalog.DatasetID\"m\n\x08Metadata\x12\x32\n\x07key_map\x18\x01 \x03(\x0b\x32!.datacatalog.Metadata.KeyMapEntry\x1a-\n\x0bKeyMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x10\x46ilterExpression\x12\x32\n\x07\x66ilters\x18\x01 \x03(\x0b\x32!.datacatalog.SinglePropertyFilter\"\x89\x03\n\x14SinglePropertyFilter\x12\x34\n\ntag_filter\x18\x01 \x01(\x0b\x32\x1e.datacatalog.TagPropertyFilterH\x00\x12@\n\x10partition_filter\x18\x02 \x01(\x0b\x32$.datacatalog.PartitionPropertyFilterH\x00\x12>\n\x0f\x61rtifact_filter\x18\x03 \x01(\x0b\x32#.datacatalog.ArtifactPropertyFilterH\x00\x12<\n\x0e\x64\x61taset_filter\x18\x04 \x01(\x0b\x32\".datacatalog.DatasetPropertyFilterH\x00\x12\x46\n\x08operator\x18\n \x01(\x0e\x32\x34.datacatalog.SinglePropertyFilter.ComparisonOperator\" \n\x12\x43omparisonOperator\x12\n\n\x06\x45QUALS\x10\x00\x42\x11\n\x0fproperty_filter\";\n\x16\x41rtifactPropertyFilter\x12\x15\n\x0b\x61rtifact_id\x18\x01 \x01(\tH\x00\x42\n\n\x08property\"3\n\x11TagPropertyFilter\x12\x12\n\x08tag_name\x18\x01 \x01(\tH\x00\x42\n\n\x08property\"S\n\x17PartitionPropertyFilter\x12,\n\x07key_val\x18\x01 \x01(\x0b\x32\x19.datacatalog.KeyValuePairH\x00\x42\n\n\x08property\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"k\n\x15\x44\x61tasetPropertyFilter\x12\x11\n\x07project\x18\x01 \x01(\tH\x00\x12\x0e\n\x04name\x18\x02 \x01(\tH\x00\x12\x10\n\x06\x64omain\x18\x03 \x01(\tH\x00\x12\x11\n\x07version\x18\x04 \x01(\tH\x00\x42\n\n\x08property\"\xf1\x01\n\x11PaginationOptions\x12\r\n\x05limit\x18\x01 \x01(\r\x12\r\n\x05token\x18\x02 \x01(\t\x12\x37\n\x07sortKey\x18\x03 \x01(\x0e\x32&.datacatalog.PaginationOptions.SortKey\x12;\n\tsortOrder\x18\x04 \x01(\x0e\x32(.datacatalog.PaginationOptions.SortOrder\"*\n\tSortOrder\x12\x0e\n\nDESCENDING\x10\x00\x12\r\n\tASCENDING\x10\x01\"\x1c\n\x07SortKey\x12\x11\n\rCREATION_TIME\x10\x00\x32\xab\x06\n\x0b\x44\x61taCatalog\x12V\n\rCreateDataset\x12!.datacatalog.CreateDatasetRequest\x1a\".datacatalog.CreateDatasetResponse\x12M\n\nGetDataset\x12\x1e.datacatalog.GetDatasetRequest\x1a\x1f.datacatalog.GetDatasetResponse\x12Y\n\x0e\x43reateArtifact\x12\".datacatalog.CreateArtifactRequest\x1a#.datacatalog.CreateArtifactResponse\x12P\n\x0bGetArtifact\x12\x1f.datacatalog.GetArtifactRequest\x1a .datacatalog.GetArtifactResponse\x12\x41\n\x06\x41\x64\x64Tag\x12\x1a.datacatalog.AddTagRequest\x1a\x1b.datacatalog.AddTagResponse\x12V\n\rListArtifacts\x12!.datacatalog.ListArtifactsRequest\x1a\".datacatalog.ListArtifactsResponse\x12S\n\x0cListDatasets\x12 .datacatalog.ListDatasetsRequest\x1a!.datacatalog.ListDatasetsResponse\x12q\n\x16GetOrExtendReservation\x12*.datacatalog.GetOrExtendReservationRequest\x1a+.datacatalog.GetOrExtendReservationResponse\x12\x65\n\x12ReleaseReservation\x12&.datacatalog.ReleaseReservationRequest\x1a\'.datacatalog.ReleaseReservationResponseb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SINGLEPROPERTYFILTER_COMPARISONOPERATOR = _descriptor.EnumDescriptor(
  name='ComparisonOperator',
  full_name='datacatalog.SinglePropertyFilter.ComparisonOperator',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUALS', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3034,
  serialized_end=3066,
)
_sym_db.RegisterEnumDescriptor(_SINGLEPROPERTYFILTER_COMPARISONOPERATOR)

_PAGINATIONOPTIONS_SORTORDER = _descriptor.EnumDescriptor(
  name='SortOrder',
  full_name='datacatalog.PaginationOptions.SortOrder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DESCENDING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASCENDING', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3609,
  serialized_end=3651,
)
_sym_db.RegisterEnumDescriptor(_PAGINATIONOPTIONS_SORTORDER)

_PAGINATIONOPTIONS_SORTKEY = _descriptor.EnumDescriptor(
  name='SortKey',
  full_name='datacatalog.PaginationOptions.SortKey',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CREATION_TIME', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3653,
  serialized_end=3681,
)
_sym_db.RegisterEnumDescriptor(_PAGINATIONOPTIONS_SORTKEY)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
  name='CreateDatasetRequest',
  full_name='datacatalog.CreateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.CreateDatasetRequest.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=211,
)


_CREATEDATASETRESPONSE = _descriptor.Descriptor(
  name='CreateDatasetResponse',
  full_name='datacatalog.CreateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=236,
)


_GETDATASETREQUEST = _descriptor.Descriptor(
  name='GetDatasetRequest',
  full_name='datacatalog.GetDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.GetDatasetRequest.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=298,
)


_GETDATASETRESPONSE = _descriptor.Descriptor(
  name='GetDatasetResponse',
  full_name='datacatalog.GetDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.GetDatasetResponse.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=359,
)


_GETARTIFACTREQUEST = _descriptor.Descriptor(
  name='GetArtifactRequest',
  full_name='datacatalog.GetArtifactRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.GetArtifactRequest.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_id', full_name='datacatalog.GetArtifactRequest.artifact_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='datacatalog.GetArtifactRequest.tag_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query_handle', full_name='datacatalog.GetArtifactRequest.query_handle',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=361,
  serialized_end=481,
)


_GETARTIFACTRESPONSE = _descriptor.Descriptor(
  name='GetArtifactResponse',
  full_name='datacatalog.GetArtifactResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact', full_name='datacatalog.GetArtifactResponse.artifact', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=545,
)


_CREATEARTIFACTREQUEST = _descriptor.Descriptor(
  name='CreateArtifactRequest',
  full_name='datacatalog.CreateArtifactRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact', full_name='datacatalog.CreateArtifactRequest.artifact', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=611,
)


_CREATEARTIFACTRESPONSE = _descriptor.Descriptor(
  name='CreateArtifactResponse',
  full_name='datacatalog.CreateArtifactResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=613,
  serialized_end=637,
)


_ADDTAGREQUEST = _descriptor.Descriptor(
  name='AddTagRequest',
  full_name='datacatalog.AddTagRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='datacatalog.AddTagRequest.tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=685,
)


_ADDTAGRESPONSE = _descriptor.Descriptor(
  name='AddTagResponse',
  full_name='datacatalog.AddTagResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=703,
)


_LISTARTIFACTSREQUEST = _descriptor.Descriptor(
  name='ListArtifactsRequest',
  full_name='datacatalog.ListArtifactsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.ListArtifactsRequest.dataset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='datacatalog.ListArtifactsRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='datacatalog.ListArtifactsRequest.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=868,
)


_LISTARTIFACTSRESPONSE = _descriptor.Descriptor(
  name='ListArtifactsResponse',
  full_name='datacatalog.ListArtifactsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifacts', full_name='datacatalog.ListArtifactsResponse.artifacts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_token', full_name='datacatalog.ListArtifactsResponse.next_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=955,
)


_LISTDATASETSREQUEST = _descriptor.Descriptor(
  name='ListDatasetsRequest',
  full_name='datacatalog.ListDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='datacatalog.ListDatasetsRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='datacatalog.ListDatasetsRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=957,
  serialized_end=1077,
)


_LISTDATASETSRESPONSE = _descriptor.Descriptor(
  name='ListDatasetsResponse',
  full_name='datacatalog.ListDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datasets', full_name='datacatalog.ListDatasetsResponse.datasets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_token', full_name='datacatalog.ListDatasetsResponse.next_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1161,
)


_RESERVATIONID = _descriptor.Descriptor(
  name='ReservationID',
  full_name='datacatalog.ReservationID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='datacatalog.ReservationID.dataset_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='datacatalog.ReservationID.tag_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1240,
)


_GETOREXTENDRESERVATIONREQUEST = _descriptor.Descriptor(
  name='GetOrExtendReservationRequest',
  full_name='datacatalog.GetOrExtendReservationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_id', full_name='datacatalog.GetOrExtendReservationRequest.reservation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='datacatalog.GetOrExtendReservationRequest.owner_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval', full_name='datacatalog.GetOrExtendReservationRequest.heartbeat_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1399,
)


_RESERVATION = _descriptor.Descriptor(
  name='Reservation',
  full_name='datacatalog.Reservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_id', full_name='datacatalog.Reservation.reservation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='datacatalog.Reservation.owner_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heartbeat_interval', full_name='datacatalog.Reservation.heartbeat_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='datacatalog.Reservation.expires_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='datacatalog.Reservation.metadata', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1629,
)


_GETOREXTENDRESERVATIONRESPONSE = _descriptor.Descriptor(
  name='GetOrExtendReservationResponse',
  full_name='datacatalog.GetOrExtendReservationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation', full_name='datacatalog.GetOrExtendReservationResponse.reservation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1710,
)


_RELEASERESERVATIONREQUEST = _descriptor.Descriptor(
  name='ReleaseReservationRequest',
  full_name='datacatalog.ReleaseReservationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_id', full_name='datacatalog.ReleaseReservationRequest.reservation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='datacatalog.ReleaseReservationRequest.owner_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1712,
  serialized_end=1809,
)


_RELEASERESERVATIONRESPONSE = _descriptor.Descriptor(
  name='ReleaseReservationResponse',
  full_name='datacatalog.ReleaseReservationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=1839,
)


_DATASET = _descriptor.Descriptor(
  name='Dataset',
  full_name='datacatalog.Dataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='datacatalog.Dataset.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='datacatalog.Dataset.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitionKeys', full_name='datacatalog.Dataset.partitionKeys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1841,
  serialized_end=1950,
)


_PARTITION = _descriptor.Descriptor(
  name='Partition',
  full_name='datacatalog.Partition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='datacatalog.Partition.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='datacatalog.Partition.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1952,
  serialized_end=1991,
)


_DATASETID = _descriptor.Descriptor(
  name='DatasetID',
  full_name='datacatalog.DatasetID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='datacatalog.DatasetID.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='datacatalog.DatasetID.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='datacatalog.DatasetID.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='datacatalog.DatasetID.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='UUID', full_name='datacatalog.DatasetID.UUID', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1993,
  serialized_end=2082,
)


_ARTIFACT = _descriptor.Descriptor(
  name='Artifact',
  full_name='datacatalog.Artifact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='datacatalog.Artifact.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.Artifact.dataset', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='datacatalog.Artifact.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='datacatalog.Artifact.metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='datacatalog.Artifact.partitions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='datacatalog.Artifact.tags', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='datacatalog.Artifact.created_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2085,
  serialized_end=2354,
)


_ARTIFACTDATA = _descriptor.Descriptor(
  name='ArtifactData',
  full_name='datacatalog.ArtifactData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='datacatalog.ArtifactData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='datacatalog.ArtifactData.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2356,
  serialized_end=2423,
)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='datacatalog.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='datacatalog.Tag.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_id', full_name='datacatalog.Tag.artifact_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='datacatalog.Tag.dataset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2506,
)


_METADATA_KEYMAPENTRY = _descriptor.Descriptor(
  name='KeyMapEntry',
  full_name='datacatalog.Metadata.KeyMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='datacatalog.Metadata.KeyMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='datacatalog.Metadata.KeyMapEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2572,
  serialized_end=2617,
)

_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='datacatalog.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_map', full_name='datacatalog.Metadata.key_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_METADATA_KEYMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2508,
  serialized_end=2617,
)


_FILTEREXPRESSION = _descriptor.Descriptor(
  name='FilterExpression',
  full_name='datacatalog.FilterExpression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='datacatalog.FilterExpression.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2619,
  serialized_end=2689,
)


_SINGLEPROPERTYFILTER = _descriptor.Descriptor(
  name='SinglePropertyFilter',
  full_name='datacatalog.SinglePropertyFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_filter', full_name='datacatalog.SinglePropertyFilter.tag_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_filter', full_name='datacatalog.SinglePropertyFilter.partition_filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_filter', full_name='datacatalog.SinglePropertyFilter.artifact_filter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_filter', full_name='datacatalog.SinglePropertyFilter.dataset_filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='datacatalog.SinglePropertyFilter.operator', index=4,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SINGLEPROPERTYFILTER_COMPARISONOPERATOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='property_filter', full_name='datacatalog.SinglePropertyFilter.property_filter',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2692,
  serialized_end=3085,
)


_ARTIFACTPROPERTYFILTER = _descriptor.Descriptor(
  name='ArtifactPropertyFilter',
  full_name='datacatalog.ArtifactPropertyFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact_id', full_name='datacatalog.ArtifactPropertyFilter.artifact_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='property', full_name='datacatalog.ArtifactPropertyFilter.property',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3087,
  serialized_end=3146,
)


_TAGPROPERTYFILTER = _descriptor.Descriptor(
  name='TagPropertyFilter',
  full_name='datacatalog.TagPropertyFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='datacatalog.TagPropertyFilter.tag_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='property', full_name='datacatalog.TagPropertyFilter.property',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3148,
  serialized_end=3199,
)


_PARTITIONPROPERTYFILTER = _descriptor.Descriptor(
  name='PartitionPropertyFilter',
  full_name='datacatalog.PartitionPropertyFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_val', full_name='datacatalog.PartitionPropertyFilter.key_val', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='property', full_name='datacatalog.PartitionPropertyFilter.property',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3201,
  serialized_end=3284,
)


_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='datacatalog.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='datacatalog.KeyValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='datacatalog.KeyValuePair.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3286,
  serialized_end=3328,
)


_DATASETPROPERTYFILTER = _descriptor.Descriptor(
  name='DatasetPropertyFilter',
  full_name='datacatalog.DatasetPropertyFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='datacatalog.DatasetPropertyFilter.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='datacatalog.DatasetPropertyFilter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='datacatalog.DatasetPropertyFilter.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='datacatalog.DatasetPropertyFilter.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='property', full_name='datacatalog.DatasetPropertyFilter.property',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3330,
  serialized_end=3437,
)


_PAGINATIONOPTIONS = _descriptor.Descriptor(
  name='PaginationOptions',
  full_name='datacatalog.PaginationOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='datacatalog.PaginationOptions.limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='datacatalog.PaginationOptions.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortKey', full_name='datacatalog.PaginationOptions.sortKey', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortOrder', full_name='datacatalog.PaginationOptions.sortOrder', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PAGINATIONOPTIONS_SORTORDER,
    _PAGINATIONOPTIONS_SORTKEY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3440,
  serialized_end=3681,
)

_CREATEDATASETREQUEST.fields_by_name['dataset'].message_type = _DATASET
_GETDATASETREQUEST.fields_by_name['dataset'].message_type = _DATASETID
_GETDATASETRESPONSE.fields_by_name['dataset'].message_type = _DATASET
_GETARTIFACTREQUEST.fields_by_name['dataset'].message_type = _DATASETID
_GETARTIFACTREQUEST.oneofs_by_name['query_handle'].fields.append(
  _GETARTIFACTREQUEST.fields_by_name['artifact_id'])
_GETARTIFACTREQUEST.fields_by_name['artifact_id'].containing_oneof = _GETARTIFACTREQUEST.oneofs_by_name['query_handle']
_GETARTIFACTREQUEST.oneofs_by_name['query_handle'].fields.append(
  _GETARTIFACTREQUEST.fields_by_name['tag_name'])
_GETARTIFACTREQUEST.fields_by_name['tag_name'].containing_oneof = _GETARTIFACTREQUEST.oneofs_by_name['query_handle']
_GETARTIFACTRESPONSE.fields_by_name['artifact'].message_type = _ARTIFACT
_CREATEARTIFACTREQUEST.fields_by_name['artifact'].message_type = _ARTIFACT
_ADDTAGREQUEST.fields_by_name['tag'].message_type = _TAG
_LISTARTIFACTSREQUEST.fields_by_name['dataset'].message_type = _DATASETID
_LISTARTIFACTSREQUEST.fields_by_name['filter'].message_type = _FILTEREXPRESSION
_LISTARTIFACTSREQUEST.fields_by_name['pagination'].message_type = _PAGINATIONOPTIONS
_LISTARTIFACTSRESPONSE.fields_by_name['artifacts'].message_type = _ARTIFACT
_LISTDATASETSREQUEST.fields_by_name['filter'].message_type = _FILTEREXPRESSION
_LISTDATASETSREQUEST.fields_by_name['pagination'].message_type = _PAGINATIONOPTIONS
_LISTDATASETSRESPONSE.fields_by_name['datasets'].message_type = _DATASET
_RESERVATIONID.fields_by_name['dataset_id'].message_type = _DATASETID
_GETOREXTENDRESERVATIONREQUEST.fields_by_name['reservation_id'].message_type = _RESERVATIONID
_GETOREXTENDRESERVATIONREQUEST.fields_by_name['heartbeat_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RESERVATION.fields_by_name['reservation_id'].message_type = _RESERVATIONID
_RESERVATION.fields_by_name['heartbeat_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RESERVATION.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RESERVATION.fields_by_name['metadata'].message_type = _METADATA
_GETOREXTENDRESERVATIONRESPONSE.fields_by_name['reservation'].message_type = _RESERVATION
_RELEASERESERVATIONREQUEST.fields_by_name['reservation_id'].message_type = _RESERVATIONID
_DATASET.fields_by_name['id'].message_type = _DATASETID
_DATASET.fields_by_name['metadata'].message_type = _METADATA
_ARTIFACT.fields_by_name['dataset'].message_type = _DATASETID
_ARTIFACT.fields_by_name['data'].message_type = _ARTIFACTDATA
_ARTIFACT.fields_by_name['metadata'].message_type = _METADATA
_ARTIFACT.fields_by_name['partitions'].message_type = _PARTITION
_ARTIFACT.fields_by_name['tags'].message_type = _TAG
_ARTIFACT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARTIFACTDATA.fields_by_name['value'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERAL
_TAG.fields_by_name['dataset'].message_type = _DATASETID
_METADATA_KEYMAPENTRY.containing_type = _METADATA
_METADATA.fields_by_name['key_map'].message_type = _METADATA_KEYMAPENTRY
_FILTEREXPRESSION.fields_by_name['filters'].message_type = _SINGLEPROPERTYFILTER
_SINGLEPROPERTYFILTER.fields_by_name['tag_filter'].message_type = _TAGPROPERTYFILTER
_SINGLEPROPERTYFILTER.fields_by_name['partition_filter'].message_type = _PARTITIONPROPERTYFILTER
_SINGLEPROPERTYFILTER.fields_by_name['artifact_filter'].message_type = _ARTIFACTPROPERTYFILTER
_SINGLEPROPERTYFILTER.fields_by_name['dataset_filter'].message_type = _DATASETPROPERTYFILTER
_SINGLEPROPERTYFILTER.fields_by_name['operator'].enum_type = _SINGLEPROPERTYFILTER_COMPARISONOPERATOR
_SINGLEPROPERTYFILTER_COMPARISONOPERATOR.containing_type = _SINGLEPROPERTYFILTER
_SINGLEPROPERTYFILTER.oneofs_by_name['property_filter'].fields.append(
  _SINGLEPROPERTYFILTER.fields_by_name['tag_filter'])
_SINGLEPROPERTYFILTER.fields_by_name['tag_filter'].containing_oneof = _SINGLEPROPERTYFILTER.oneofs_by_name['property_filter']
_SINGLEPROPERTYFILTER.oneofs_by_name['property_filter'].fields.append(
  _SINGLEPROPERTYFILTER.fields_by_name['partition_filter'])
_SINGLEPROPERTYFILTER.fields_by_name['partition_filter'].containing_oneof = _SINGLEPROPERTYFILTER.oneofs_by_name['property_filter']
_SINGLEPROPERTYFILTER.oneofs_by_name['property_filter'].fields.append(
  _SINGLEPROPERTYFILTER.fields_by_name['artifact_filter'])
_SINGLEPROPERTYFILTER.fields_by_name['artifact_filter'].containing_oneof = _SINGLEPROPERTYFILTER.oneofs_by_name['property_filter']
_SINGLEPROPERTYFILTER.oneofs_by_name['property_filter'].fields.append(
  _SINGLEPROPERTYFILTER.fields_by_name['dataset_filter'])
_SINGLEPROPERTYFILTER.fields_by_name['dataset_filter'].containing_oneof = _SINGLEPROPERTYFILTER.oneofs_by_name['property_filter']
_ARTIFACTPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _ARTIFACTPROPERTYFILTER.fields_by_name['artifact_id'])
_ARTIFACTPROPERTYFILTER.fields_by_name['artifact_id'].containing_oneof = _ARTIFACTPROPERTYFILTER.oneofs_by_name['property']
_TAGPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _TAGPROPERTYFILTER.fields_by_name['tag_name'])
_TAGPROPERTYFILTER.fields_by_name['tag_name'].containing_oneof = _TAGPROPERTYFILTER.oneofs_by_name['property']
_PARTITIONPROPERTYFILTER.fields_by_name['key_val'].message_type = _KEYVALUEPAIR
_PARTITIONPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _PARTITIONPROPERTYFILTER.fields_by_name['key_val'])
_PARTITIONPROPERTYFILTER.fields_by_name['key_val'].containing_oneof = _PARTITIONPROPERTYFILTER.oneofs_by_name['property']
_DATASETPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _DATASETPROPERTYFILTER.fields_by_name['project'])
_DATASETPROPERTYFILTER.fields_by_name['project'].containing_oneof = _DATASETPROPERTYFILTER.oneofs_by_name['property']
_DATASETPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _DATASETPROPERTYFILTER.fields_by_name['name'])
_DATASETPROPERTYFILTER.fields_by_name['name'].containing_oneof = _DATASETPROPERTYFILTER.oneofs_by_name['property']
_DATASETPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _DATASETPROPERTYFILTER.fields_by_name['domain'])
_DATASETPROPERTYFILTER.fields_by_name['domain'].containing_oneof = _DATASETPROPERTYFILTER.oneofs_by_name['property']
_DATASETPROPERTYFILTER.oneofs_by_name['property'].fields.append(
  _DATASETPROPERTYFILTER.fields_by_name['version'])
_DATASETPROPERTYFILTER.fields_by_name['version'].containing_oneof = _DATASETPROPERTYFILTER.oneofs_by_name['property']
_PAGINATIONOPTIONS.fields_by_name['sortKey'].enum_type = _PAGINATIONOPTIONS_SORTKEY
_PAGINATIONOPTIONS.fields_by_name['sortOrder'].enum_type = _PAGINATIONOPTIONS_SORTORDER
_PAGINATIONOPTIONS_SORTORDER.containing_type = _PAGINATIONOPTIONS
_PAGINATIONOPTIONS_SORTKEY.containing_type = _PAGINATIONOPTIONS
DESCRIPTOR.message_types_by_name['CreateDatasetRequest'] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasetResponse'] = _CREATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetRequest'] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name['GetDatasetResponse'] = _GETDATASETRESPONSE
DESCRIPTOR.message_types_by_name['GetArtifactRequest'] = _GETARTIFACTREQUEST
DESCRIPTOR.message_types_by_name['GetArtifactResponse'] = _GETARTIFACTRESPONSE
DESCRIPTOR.message_types_by_name['CreateArtifactRequest'] = _CREATEARTIFACTREQUEST
DESCRIPTOR.message_types_by_name['CreateArtifactResponse'] = _CREATEARTIFACTRESPONSE
DESCRIPTOR.message_types_by_name['AddTagRequest'] = _ADDTAGREQUEST
DESCRIPTOR.message_types_by_name['AddTagResponse'] = _ADDTAGRESPONSE
DESCRIPTOR.message_types_by_name['ListArtifactsRequest'] = _LISTARTIFACTSREQUEST
DESCRIPTOR.message_types_by_name['ListArtifactsResponse'] = _LISTARTIFACTSRESPONSE
DESCRIPTOR.message_types_by_name['ListDatasetsRequest'] = _LISTDATASETSREQUEST
DESCRIPTOR.message_types_by_name['ListDatasetsResponse'] = _LISTDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['ReservationID'] = _RESERVATIONID
DESCRIPTOR.message_types_by_name['GetOrExtendReservationRequest'] = _GETOREXTENDRESERVATIONREQUEST
DESCRIPTOR.message_types_by_name['Reservation'] = _RESERVATION
DESCRIPTOR.message_types_by_name['GetOrExtendReservationResponse'] = _GETOREXTENDRESERVATIONRESPONSE
DESCRIPTOR.message_types_by_name['ReleaseReservationRequest'] = _RELEASERESERVATIONREQUEST
DESCRIPTOR.message_types_by_name['ReleaseReservationResponse'] = _RELEASERESERVATIONRESPONSE
DESCRIPTOR.message_types_by_name['Dataset'] = _DATASET
DESCRIPTOR.message_types_by_name['Partition'] = _PARTITION
DESCRIPTOR.message_types_by_name['DatasetID'] = _DATASETID
DESCRIPTOR.message_types_by_name['Artifact'] = _ARTIFACT
DESCRIPTOR.message_types_by_name['ArtifactData'] = _ARTIFACTDATA
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.message_types_by_name['FilterExpression'] = _FILTEREXPRESSION
DESCRIPTOR.message_types_by_name['SinglePropertyFilter'] = _SINGLEPROPERTYFILTER
DESCRIPTOR.message_types_by_name['ArtifactPropertyFilter'] = _ARTIFACTPROPERTYFILTER
DESCRIPTOR.message_types_by_name['TagPropertyFilter'] = _TAGPROPERTYFILTER
DESCRIPTOR.message_types_by_name['PartitionPropertyFilter'] = _PARTITIONPROPERTYFILTER
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['DatasetPropertyFilter'] = _DATASETPROPERTYFILTER
DESCRIPTOR.message_types_by_name['PaginationOptions'] = _PAGINATIONOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEDATASETREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.CreateDatasetRequest)
  ))
_sym_db.RegisterMessage(CreateDatasetRequest)

CreateDatasetResponse = _reflection.GeneratedProtocolMessageType('CreateDatasetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEDATASETRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.CreateDatasetResponse)
  ))
_sym_db.RegisterMessage(CreateDatasetResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDATASETREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.GetDatasetRequest)
  ))
_sym_db.RegisterMessage(GetDatasetRequest)

GetDatasetResponse = _reflection.GeneratedProtocolMessageType('GetDatasetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDATASETRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.GetDatasetResponse)
  ))
_sym_db.RegisterMessage(GetDatasetResponse)

GetArtifactRequest = _reflection.GeneratedProtocolMessageType('GetArtifactRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETARTIFACTREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.GetArtifactRequest)
  ))
_sym_db.RegisterMessage(GetArtifactRequest)

GetArtifactResponse = _reflection.GeneratedProtocolMessageType('GetArtifactResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETARTIFACTRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.GetArtifactResponse)
  ))
_sym_db.RegisterMessage(GetArtifactResponse)

CreateArtifactRequest = _reflection.GeneratedProtocolMessageType('CreateArtifactRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEARTIFACTREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.CreateArtifactRequest)
  ))
_sym_db.RegisterMessage(CreateArtifactRequest)

CreateArtifactResponse = _reflection.GeneratedProtocolMessageType('CreateArtifactResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEARTIFACTRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.CreateArtifactResponse)
  ))
_sym_db.RegisterMessage(CreateArtifactResponse)

AddTagRequest = _reflection.GeneratedProtocolMessageType('AddTagRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDTAGREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.AddTagRequest)
  ))
_sym_db.RegisterMessage(AddTagRequest)

AddTagResponse = _reflection.GeneratedProtocolMessageType('AddTagResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDTAGRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.AddTagResponse)
  ))
_sym_db.RegisterMessage(AddTagResponse)

ListArtifactsRequest = _reflection.GeneratedProtocolMessageType('ListArtifactsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTARTIFACTSREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ListArtifactsRequest)
  ))
_sym_db.RegisterMessage(ListArtifactsRequest)

ListArtifactsResponse = _reflection.GeneratedProtocolMessageType('ListArtifactsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTARTIFACTSRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ListArtifactsResponse)
  ))
_sym_db.RegisterMessage(ListArtifactsResponse)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTDATASETSREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ListDatasetsRequest)
  ))
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTDATASETSRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ListDatasetsResponse)
  ))
_sym_db.RegisterMessage(ListDatasetsResponse)

ReservationID = _reflection.GeneratedProtocolMessageType('ReservationID', (_message.Message,), dict(
  DESCRIPTOR = _RESERVATIONID,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ReservationID)
  ))
_sym_db.RegisterMessage(ReservationID)

GetOrExtendReservationRequest = _reflection.GeneratedProtocolMessageType('GetOrExtendReservationRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETOREXTENDRESERVATIONREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.GetOrExtendReservationRequest)
  ))
_sym_db.RegisterMessage(GetOrExtendReservationRequest)

Reservation = _reflection.GeneratedProtocolMessageType('Reservation', (_message.Message,), dict(
  DESCRIPTOR = _RESERVATION,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.Reservation)
  ))
_sym_db.RegisterMessage(Reservation)

GetOrExtendReservationResponse = _reflection.GeneratedProtocolMessageType('GetOrExtendReservationResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETOREXTENDRESERVATIONRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.GetOrExtendReservationResponse)
  ))
_sym_db.RegisterMessage(GetOrExtendReservationResponse)

ReleaseReservationRequest = _reflection.GeneratedProtocolMessageType('ReleaseReservationRequest', (_message.Message,), dict(
  DESCRIPTOR = _RELEASERESERVATIONREQUEST,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ReleaseReservationRequest)
  ))
_sym_db.RegisterMessage(ReleaseReservationRequest)

ReleaseReservationResponse = _reflection.GeneratedProtocolMessageType('ReleaseReservationResponse', (_message.Message,), dict(
  DESCRIPTOR = _RELEASERESERVATIONRESPONSE,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ReleaseReservationResponse)
  ))
_sym_db.RegisterMessage(ReleaseReservationResponse)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), dict(
  DESCRIPTOR = _DATASET,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.Dataset)
  ))
_sym_db.RegisterMessage(Dataset)

Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), dict(
  DESCRIPTOR = _PARTITION,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.Partition)
  ))
_sym_db.RegisterMessage(Partition)

DatasetID = _reflection.GeneratedProtocolMessageType('DatasetID', (_message.Message,), dict(
  DESCRIPTOR = _DATASETID,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.DatasetID)
  ))
_sym_db.RegisterMessage(DatasetID)

Artifact = _reflection.GeneratedProtocolMessageType('Artifact', (_message.Message,), dict(
  DESCRIPTOR = _ARTIFACT,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.Artifact)
  ))
_sym_db.RegisterMessage(Artifact)

ArtifactData = _reflection.GeneratedProtocolMessageType('ArtifactData', (_message.Message,), dict(
  DESCRIPTOR = _ARTIFACTDATA,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ArtifactData)
  ))
_sym_db.RegisterMessage(ArtifactData)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), dict(
  DESCRIPTOR = _TAG,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.Tag)
  ))
_sym_db.RegisterMessage(Tag)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), dict(

  KeyMapEntry = _reflection.GeneratedProtocolMessageType('KeyMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _METADATA_KEYMAPENTRY,
    __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
    # @@protoc_insertion_point(class_scope:datacatalog.Metadata.KeyMapEntry)
    ))
  ,
  DESCRIPTOR = _METADATA,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.Metadata)
  ))
_sym_db.RegisterMessage(Metadata)
_sym_db.RegisterMessage(Metadata.KeyMapEntry)

FilterExpression = _reflection.GeneratedProtocolMessageType('FilterExpression', (_message.Message,), dict(
  DESCRIPTOR = _FILTEREXPRESSION,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.FilterExpression)
  ))
_sym_db.RegisterMessage(FilterExpression)

SinglePropertyFilter = _reflection.GeneratedProtocolMessageType('SinglePropertyFilter', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEPROPERTYFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.SinglePropertyFilter)
  ))
_sym_db.RegisterMessage(SinglePropertyFilter)

ArtifactPropertyFilter = _reflection.GeneratedProtocolMessageType('ArtifactPropertyFilter', (_message.Message,), dict(
  DESCRIPTOR = _ARTIFACTPROPERTYFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.ArtifactPropertyFilter)
  ))
_sym_db.RegisterMessage(ArtifactPropertyFilter)

TagPropertyFilter = _reflection.GeneratedProtocolMessageType('TagPropertyFilter', (_message.Message,), dict(
  DESCRIPTOR = _TAGPROPERTYFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.TagPropertyFilter)
  ))
_sym_db.RegisterMessage(TagPropertyFilter)

PartitionPropertyFilter = _reflection.GeneratedProtocolMessageType('PartitionPropertyFilter', (_message.Message,), dict(
  DESCRIPTOR = _PARTITIONPROPERTYFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.PartitionPropertyFilter)
  ))
_sym_db.RegisterMessage(PartitionPropertyFilter)

KeyValuePair = _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), dict(
  DESCRIPTOR = _KEYVALUEPAIR,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.KeyValuePair)
  ))
_sym_db.RegisterMessage(KeyValuePair)

DatasetPropertyFilter = _reflection.GeneratedProtocolMessageType('DatasetPropertyFilter', (_message.Message,), dict(
  DESCRIPTOR = _DATASETPROPERTYFILTER,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.DatasetPropertyFilter)
  ))
_sym_db.RegisterMessage(DatasetPropertyFilter)

PaginationOptions = _reflection.GeneratedProtocolMessageType('PaginationOptions', (_message.Message,), dict(
  DESCRIPTOR = _PAGINATIONOPTIONS,
  __module__ = 'flyteidl.datacatalog.datacatalog_pb2'
  # @@protoc_insertion_point(class_scope:datacatalog.PaginationOptions)
  ))
_sym_db.RegisterMessage(PaginationOptions)


_METADATA_KEYMAPENTRY._options = None

_DATACATALOG = _descriptor.ServiceDescriptor(
  name='DataCatalog',
  full_name='datacatalog.DataCatalog',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3684,
  serialized_end=4495,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDataset',
    full_name='datacatalog.DataCatalog.CreateDataset',
    index=0,
    containing_service=None,
    input_type=_CREATEDATASETREQUEST,
    output_type=_CREATEDATASETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataset',
    full_name='datacatalog.DataCatalog.GetDataset',
    index=1,
    containing_service=None,
    input_type=_GETDATASETREQUEST,
    output_type=_GETDATASETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateArtifact',
    full_name='datacatalog.DataCatalog.CreateArtifact',
    index=2,
    containing_service=None,
    input_type=_CREATEARTIFACTREQUEST,
    output_type=_CREATEARTIFACTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetArtifact',
    full_name='datacatalog.DataCatalog.GetArtifact',
    index=3,
    containing_service=None,
    input_type=_GETARTIFACTREQUEST,
    output_type=_GETARTIFACTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddTag',
    full_name='datacatalog.DataCatalog.AddTag',
    index=4,
    containing_service=None,
    input_type=_ADDTAGREQUEST,
    output_type=_ADDTAGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListArtifacts',
    full_name='datacatalog.DataCatalog.ListArtifacts',
    index=5,
    containing_service=None,
    input_type=_LISTARTIFACTSREQUEST,
    output_type=_LISTARTIFACTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatasets',
    full_name='datacatalog.DataCatalog.ListDatasets',
    index=6,
    containing_service=None,
    input_type=_LISTDATASETSREQUEST,
    output_type=_LISTDATASETSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrExtendReservation',
    full_name='datacatalog.DataCatalog.GetOrExtendReservation',
    index=7,
    containing_service=None,
    input_type=_GETOREXTENDRESERVATIONREQUEST,
    output_type=_GETOREXTENDRESERVATIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReleaseReservation',
    full_name='datacatalog.DataCatalog.ReleaseReservation',
    index=8,
    containing_service=None,
    input_type=_RELEASERESERVATIONREQUEST,
    output_type=_RELEASERESERVATIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATACATALOG)

DESCRIPTOR.services_by_name['DataCatalog'] = _DATACATALOG

# @@protoc_insertion_point(module_scope)
